==> mariadb-connector-java_2.3.0.orig.tar.xz: mariadb-connector-j-2.3.0/src/main/java/org/mariadb/jdbc/BlobOutputStream.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Output stream for the blob.
 */
class BlobOutputStream extends OutputStream {

  private final MariaDbBlob blob;
  private int pos;

  public BlobOutputStream(MariaDbBlob blob, int pos) {
    this.blob = blob;
    this.pos = pos;
  }

  @Override
  public void write(int bit) throws IOException {

    if (this.pos >= blob.length) {
      byte[] tmp = new byte[2 * blob.length + 1];
      System.arraycopy(blob.data, blob.offset, tmp, 0, blob.length);
      blob.data = tmp;
      pos -= blob.offset;
      blob.offset = 0;
      blob.length++;
    }
    blob.data[pos] = (byte) bit;
    pos++;
  }

  @Override
  public void write(byte[] buf, int off, int len) throws IOException {
    if (off < 0) {
      throw new IOException("Invalid offset " + off);
    }
    int realLen = Math.min(buf.length - off, len);
    if (pos + realLen >= blob.length) {
      int newLen = 2 * blob.length + realLen;
      byte[] tmp = new byte[newLen];
      System.arraycopy(blob.data, blob.offset, tmp, 0, blob.length);
      blob.data = tmp;
      pos -= blob.offset;
      blob.offset = 0;
      blob.length = pos + realLen;
    }
    System.arraycopy(buf, off, blob.data, pos, realLen);
    pos += realLen;
  }

  @Override
  public void write(byte[] buf) throws IOException {
    write(buf, 0, buf.length);
  }
}

==> mariadb-connector-java_2.5.3.orig.tar.xz: mariadb-connector-j-2.5.3/src/main/java/org/mariadb/jdbc/BlobOutputStream.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2019 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import java.io.*;

/** Output stream for the blob. */
class BlobOutputStream extends OutputStream {

  private final MariaDbBlob blob;
  private int pos;

  public BlobOutputStream(MariaDbBlob blob, int pos) {
    this.blob = blob;
    this.pos = pos;
  }

  @Override
  public void write(int bit) throws IOException {

    if (this.pos >= blob.length) {
      byte[] tmp = new byte[2 * blob.length + 1];
      System.arraycopy(blob.data, blob.offset, tmp, 0, blob.length);
      blob.data = tmp;
      pos -= blob.offset;
      blob.offset = 0;
      blob.length++;
    }
    blob.data[pos] = (byte) bit;
    pos++;
  }

  @Override
  public void write(byte[] buf, int off, int len) throws IOException {
    if (off < 0) {
      throw new IOException("Invalid offset " + off);
    }
    int realLen = Math.min(buf.length - off, len);
    if (pos + realLen >= blob.length) {
      int newLen = 2 * blob.length + realLen;
      byte[] tmp = new byte[newLen];
      System.arraycopy(blob.data, blob.offset, tmp, 0, blob.length);
      blob.data = tmp;
      pos -= blob.offset;
      blob.offset = 0;
      blob.length = pos + realLen;
    }
    System.arraycopy(buf, off, blob.data, pos, realLen);
    pos += realLen;
  }

  @Override
  public void write(byte[] buf) throws IOException {
    write(buf, 0, buf.length);
  }
}
